package mjml

import (
	"testing"

	"github.com/stretchr/testify/require"
)

func BenchmarkDukTapeInit(b *testing.B) {
	for i := 0; i < b.N; i++ {
		ctx, err := initDukTapeCtx()
		require.NoError(b, err)
		ctx.DestroyHeap()
	}
}

func BenchmarkDukTapeRender(b *testing.B) {
	ctx, err := initDukTapeCtx()
	require.NoError(b, err)
	defer ctx.DestroyHeap()
	b.ResetTimer()
	for i := 0; i < b.N; i++ {
		_, err := renderDukTape(ctx, mjmlSrc, Options{
			Beautify:        true,
			ValidationLevel: ValidationStrict,
		})
		require.NoError(b, err)
	}
}

/*
func BenchmarkGojaInit(b *testing.B) {
	for i := 0; i < b.N; i++ {
		_, err := initGoja()
		require.NoError(b, err)
	}
}

func BenchmarkGojaRender(b *testing.B) {
	vm, err := initGoja()
	require.NoError(b, err)
	b.ResetTimer()
	for i := 0; i < b.N; i++ {
		renderGoja(vm, mjmlSrc)
	}
}
*/

var mjmlSrcWithError = `
<mjml>
  <mj-body>
    <mj-section invalid="hi">
      <mj-column>
        <mj-text invalid=true>hello world</mj-text>
      </mj-column>
    </mj-section>
  </mj-body>
</mjml>
`

func TestDukType(t *testing.T) {
	t.Run("Simple", func(t *testing.T) {
		ctx, err := initDukTapeCtx()
		require.NoError(t, err)
		defer ctx.DestroyHeap()
		t.Log(renderDukTape(ctx, mjmlSrc, Options{
			Beautify:        true,
			ValidationLevel: ValidationStrict,
		}))
	})
	t.Run("WithError", func(t *testing.T) {
		ctx, err := initDukTapeCtx()
		require.NoError(t, err)
		defer ctx.DestroyHeap()
		r, err := renderDukTape(ctx, mjmlSrcWithError, Options{
			Beautify:        true,
			ValidationLevel: ValidationSoft,
		})
		require.NoError(t, err)
		t.Log(r)
	})
}

/*
func TestGoja(t *testing.T) {
	vm, err := initGoja()
	require.NoError(t, err)
	renderGoja(vm, mjmlSrc)
}
*/
