package tests

import (
	"net/http"
	"testing"

	"github.com/stretchr/testify/assert"
	"github.com/stretchr/testify/require"
	"orus.io/orus-io/rednerd/models"
)

func TestUserManagement(t *testing.T) {
	tester := NewAPITester(t)
	defer tester.Close()

	defer tester.Logout()
	tester.Login("admin", "admin")

	var failed bool

	for _, tt := range []struct {
		name string
		test func(t *testing.T)
	}{
		{"Create",
			func(t *testing.T) {
				var info models.Userinfo
				require.Equal(t, http.StatusCreated,
					tester.MustPostJSON("/api/v1/user", JSONObj{
						"username": "janedoe",
					}, &info))
				assert.Equal(t, "janedoe", info.Username)
				assert.False(t, info.IsAdmin)
			}},
		{"Get",
			func(t *testing.T) {
				var info models.Userinfo
				require.Equal(t, http.StatusOK,
					tester.MustGetJSON("/api/v1/user/janedoe", &info),
				)
				assert.Equal(t, "janedoe", info.Username)
				assert.False(t, info.IsAdmin)
			}},
		{"List",
			func(t *testing.T) {
				var infoList []models.Userinfo
				require.Equal(t, http.StatusOK,
					tester.MustGetJSON("/api/v1/user", &infoList))
				assert.Equal(t, 2, len(infoList))
				assert.Contains(t, infoList, models.Userinfo{Username: "admin", IsAdmin: true})
				assert.Contains(t, infoList, models.Userinfo{Username: "janedoe", IsAdmin: false})
			}},
	} {
		if failed {
			break
		}
		failed = !tester.Run(tt.name, func(t *testing.T) {
			tt.test(t)
		})
	}
}
